@@ -15,11 +15,13 @@ logger = logging.getLogger(
 
 
 class TaskHandler:
+    metrics_provider_process = None
+
     def __init__(
             self,
             workers: List[WorkerInterface],
             configuration: Configuration = None,
-            metrics_settings: MetricsSettings = MetricsSettings()
+            metrics_settings: MetricsSettings = None
     ):
         if not isinstance(workers, list):
             raise Exception('Invalid worker list')
@@ -47,6 +49,8 @@ class TaskHandler:
         logger.info('Joined all processes')
 
     def __create_metrics_provider_process(self, metrics_settings: MetricsSettings) -> None:
+        if metrics_settings == None:
+            return
         self.metrics_provider_process = Process(
             target=provide_metrics,
             args=(metrics_settings,)
@@ -79,6 +83,8 @@ class TaskHandler:
         self.task_runner_processes.append(process)
 
     def __start_metrics_provider_process(self):
+        if self.metrics_provider_process == None:
+            return
         self.metrics_provider_process.start()
         logger.info('Started MetricsProvider process')
 
@@ -88,6 +94,8 @@ class TaskHandler:
         logger.info('Started TaskRunner processes')
 
     def __join_metrics_provider_process(self):
+        if self.metrics_provider_process == None:
+            return
         self.metrics_provider_process.join()
         logger.info('Joined MetricsProvider processes')
 
@@ -111,5 +119,5 @@ class TaskHandler:
             logger.info(f'Killed process: {process}')
         except Exception as e:
             logger.debug(f'Failed to kill process: {process}, reason: {e}')
-            self.metrics_provider_process.terminate()
+            process.terminate()
             logger.info('Terminated process: {process}')
